@@ -71,16 +71,13 @@ void MainWindow::showExpanded()
 
 void MainWindow::on_pushButtonStart_clicked()
 {
-    QProcess *process;
-            process = new QProcess( this );
-            process->start("opt/tenminutecore/script/tenminutecore.sh");
-            process->waitForFinished();
+    QProcess process;
+    process.start("sh /opt/tenminutecore/script/tenminutecore.sh");
 }
 
 void MainWindow::on_pushButtonStop_clicked()
 {
-    QProcess *process;
-            process = new QProcess( this );
-            process->start("opt/tenminutecore/script/kill.sh");
-            process->waitForFinished();
+    QProcess process;
+    process.start("sh /opt/tenminutecore/script/kill.sh");
+    process.waitForFinished();
 }
